package com.ozs.web.controller.accountmanagment;


import com.ozs.common.annotation.Log;
import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.enums.BusinessType;
import com.ozs.common.utils.poi.ExcelUtil;
import com.ozs.service.entity.vo.BaseDeviceResumeVo;
import com.ozs.service.entity.vo.DeviceResumeResp;
import com.ozs.service.service.BaseDeviceResumeService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Administrator
 */
@RestController
@RequestMapping("/service/BaseDeviceResume")
@Slf4j
public class BaseDeviceResumeController extends BaseController {

    @Autowired
    private BaseDeviceResumeService baseDeviceResumeService;

    /**
     * 获取设备状态履历
     */
    @GetMapping("/getBaseDeviceResume")
    @Log(title = "设备状态履历", businessType = BusinessType.SELECT)
    public AjaxResult getBaseDeviceResume(@RequestParam(value = "cameraCode") String cameraCode,
                                          @RequestParam(value = "startTime", required = false) String startTime,
                                          @RequestParam(value = "endTime", required = false) String endTime) {
        List<BaseDeviceResumeVo> baseDevicResumeVoList = baseDeviceResumeService.getBaseDeviceResume(cameraCode, startTime, endTime);
        List<BaseDeviceResumeVo> baseDeviceResumeVos = removeAdjacentFaults(baseDevicResumeVoList);
        return AjaxResult.success(baseDeviceResumeVos);
    }

    /**
     * 导出设备状态履历
     *
     * @param response
     */
    @GetMapping("/exportDeviceResume")
    @Log(title = "设备状态履历", businessType = BusinessType.EXPORT)
    public void exportDeviceResume(HttpServletResponse response, @RequestParam(value = "cameraCode") String cameraCode,
                                   @RequestParam(value ="startTime", required = false) String startTime,
                                   @RequestParam(value ="endTime", required = false) String endTime) {
        List<DeviceResumeResp> deviceResumeRespList = baseDeviceResumeService.exportDeviceResume(cameraCode, startTime, endTime);
        ExcelUtil<DeviceResumeResp> util = new ExcelUtil<>(DeviceResumeResp.class);
        util.exportExcel(response, deviceResumeRespList, "设备状态履历数据");
    }


    public static List<BaseDeviceResumeVo> removeAdjacentFaults(List<BaseDeviceResumeVo> records) {
        List<BaseDeviceResumeVo> resultList = new ArrayList<>();
        for (int i = 0; i < records.size(); i++) {
            if (i == 0 || !records.get(i).getIsDisable().equals(records.get(i - 1).getIsDisable()) || "设备正常".equals(records.get(i).getIsDisable())) {
                resultList.add(records.get(i));
            }
        }
        return resultList;
    }
}
